**Formative** is a self-hosted web app for collecting form responses and
files. For application forms, you can use it together with
[reviewpanel](https://github.com/johncronan/reviewpanel) to review and score
applicant submissions.

Development of Formative was funded by
[Public Media Institute](https://publicmediainstitute.com), with support from
[The Andy Warhol Foundation for the Visual Arts](https://warholfoundation.org).
